aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--.gitignore4
-rw-r--r--AUTHORS11
-rw-r--r--CHANGES6
-rw-r--r--MANIFEST.in10
-rw-r--r--Makefile2
-rw-r--r--README17
-rw-r--r--README.api20
-rwxr-xr-xbin/lord (renamed from bin/layman)6
-rw-r--r--doc/Makefile8
-rw-r--r--doc/layman.8.xml220
-rw-r--r--etc/cache.xml38
-rw-r--r--etc/layman.cfg18
-rw-r--r--layman/.svn.ignore1
-rw-r--r--layman/overlays/.svn.ignore1
-rw-r--r--overlord/__init__.py (renamed from layman/__init__.py)0
-rw-r--r--overlord/api.py (renamed from layman/api.py)48
-rw-r--r--overlord/cli.py (renamed from layman/cli.py)14
-rw-r--r--overlord/config.py (renamed from layman/config.py)28
-rw-r--r--overlord/constants.py (renamed from layman/constants.py)6
-rw-r--r--overlord/db.py (renamed from layman/db.py)14
-rw-r--r--overlord/dbbase.py (renamed from layman/dbbase.py)8
-rw-r--r--overlord/debug.py (renamed from layman/debug.py)8
-rw-r--r--overlord/makeconf.py (renamed from layman/makeconf.py)2
-rw-r--r--overlord/overlays/__init__.py (renamed from layman/overlays/__init__.py)0
-rw-r--r--overlord/overlays/bzr.py (renamed from layman/overlays/bzr.py)6
-rw-r--r--overlord/overlays/cvs.py (renamed from layman/overlays/cvs.py)6
-rw-r--r--overlord/overlays/darcs.py (renamed from layman/overlays/darcs.py)6
-rw-r--r--overlord/overlays/g_common.py (renamed from layman/overlays/g_common.py)8
-rw-r--r--overlord/overlays/git.py (renamed from layman/overlays/git.py)6
-rw-r--r--overlord/overlays/mercurial.py (renamed from layman/overlays/mercurial.py)6
-rw-r--r--overlord/overlays/overlay.py (renamed from layman/overlays/overlay.py)26
-rw-r--r--overlord/overlays/rsync.py (renamed from layman/overlays/rsync.py)6
-rw-r--r--overlord/overlays/source.py (renamed from layman/overlays/source.py)6
-rw-r--r--overlord/overlays/svn.py (renamed from layman/overlays/svn.py)6
-rw-r--r--overlord/overlays/tar.py (renamed from layman/overlays/tar.py)16
-rw-r--r--overlord/tests/dtest.py (renamed from layman/tests/dtest.py)30
-rw-r--r--overlord/tests/external.py (renamed from layman/tests/external.py)8
-rw-r--r--overlord/tests/pylintrc (renamed from layman/tests/pylintrc)0
-rw-r--r--overlord/tests/testfiles/global-overlays.xml (renamed from layman/tests/testfiles/global-overlays.xml)0
-rw-r--r--overlord/tests/testfiles/layman-test.tar.bz2 (renamed from layman/tests/testfiles/layman-test.tar.bz2)bin845 -> 845 bytes
-rw-r--r--overlord/tests/testfiles/make.conf (renamed from layman/tests/testfiles/make.conf)0
-rw-r--r--overlord/tests/testfiles/overlays_bug_184449.xml (renamed from layman/tests/testfiles/overlays_bug_184449.xml)0
-rw-r--r--overlord/tests/testfiles/overlays_bug_286290.xml (renamed from layman/tests/testfiles/overlays_bug_286290.xml)0
-rw-r--r--overlord/tests/testfiles/subpath-1.xml (renamed from layman/tests/testfiles/subpath-1.xml)0
-rw-r--r--overlord/tests/testfiles/subpath-2.xml (renamed from layman/tests/testfiles/subpath-2.xml)0
-rw-r--r--overlord/utils.py (renamed from layman/utils.py)2
-rw-r--r--overlord/version.py (renamed from layman/version.py)2
-rwxr-xr-xsetup.py20
-rwxr-xr-xtestsuite.sh9
49 files changed, 336 insertions, 323 deletions
diff --git a/.gitignore b/.gitignore
index e5c950c..f6b3eef 100644
--- a/.gitignore
+++ b/.gitignore
@@ -1,7 +1,7 @@
*~
*.pyc
-/doc/layman.8
-/doc/layman.8.html
+/doc/overlord.8
+/doc/overlord.8.html
/dist
/MANIFEST
*.patch
diff --git a/AUTHORS b/AUTHORS
index e5de2e3..c388534 100644
--- a/AUTHORS
+++ b/AUTHORS
@@ -1,7 +1,9 @@
AUTHORS
-------
-Written by
+Original Layman Authors
+
+Written by
Gunnar Wrobel (wrobel@gentoo.org)
@@ -21,3 +23,10 @@ Martin von Gagern (Martin.vGagern@gmx.net) - Better list format.
Sebastian Pipping (sebastian@pipping.org) - repositories.xml support
- ElementTree migration
Christian Groschupp (christian@groschupp.org) - ElementTree migration
+
+
+Overlord rewrite
+
+ Brian Dolbec <brian.dolbec@gmail.com>
+
+ Detlev Cazanova <detlev.casanova@gmail.com> - C-interface lib
diff --git a/CHANGES b/CHANGES
index 908f03e..4bed500 100644
--- a/CHANGES
+++ b/CHANGES
@@ -1,6 +1,12 @@
CHANGES
-------
+Overlord history
+
+Migration to overlord namespace and new git repo on overlays.gentoo.org
+
+Layman history
+
Version 1.4.1 - Released 2010-07-09
===================================
diff --git a/MANIFEST.in b/MANIFEST.in
index bc52dea..bfb07d8 100644
--- a/MANIFEST.in
+++ b/MANIFEST.in
@@ -4,8 +4,8 @@ include COPYING
include INSTALL
include README
include RELEASE_NOTES
-include etc/layman.cfg
-include doc/layman.8
-include doc/layman.8.html
-include doc/layman.8.xml
-recursive-include layman/tests *
+include etc/overlord.cfg
+include doc/overlord.8
+include doc/overlord.8.html
+include doc/overlord.8.xml
+recursive-include overlord/tests *
diff --git a/Makefile b/Makefile
index 05b8f9b..5b2ff8e 100644
--- a/Makefile
+++ b/Makefile
@@ -4,7 +4,7 @@ doc:
.PHONY: www
www:
- cp doc/layman.8.html www/index.html
+ cp doc/overlord.8.html www/index.html
.PHONY: dist
dist: doc
diff --git a/README b/README
index 8878afc..76ce140 100644
--- a/README
+++ b/README
@@ -10,29 +10,24 @@ README
About
-----
-layman is the Gentoo overlay manager and allows to integrate
+Overlord is the Gentoo overlay manager and allows to integrate
experimental software packages into the main distribution. It can also
be used as a manager for version control repositories.
+Overlord originated from another app called Layman.
+
Links
-----
Primary project web site:
- - http://layman.sourceforge.net/
-
-Project site on SourceForge:
-
- - http://sourceforge.net/projects/layman
-
-Project summary on Ohloh:
+ - http://
- - http://ohloh.net/projects/layman/
+Project site on Gentoo:
-Project summary on Freshmeat:
+ - http://
- - http://freshmeat.net/projects/layman/
Bug tracker:
diff --git a/README.api b/README.api
index 976006d..3cdf337 100644
--- a/README.api
+++ b/README.api
@@ -1,21 +1,21 @@
-New layman API readme:
+Overlord API readme:
-To use the new LaymanAPI class, so far this is what I've come up with.
+To use the new OverlordAPI class, so far this is what I've come up with.
-big_daddy layman # python
-Python 2.6.5 (release26-maint, May 15 2010, 18:26:37)
+big_daddy overlord # python
+Python 2.6.5 (release26-maint, May 15 2010, 18:26:37)
[GCC 4.4.3] on linux2
Type "help", "copyright", "credits" or "license" for more information.
->>> import layman;from layman.api import LaymanAPI, create_fd;from layman.config import BareConfig
->>> e=create_fd();o=create_fd();from layman.debug import Message;M=Message(module='layman',out=o[1], err=e[1]);c=BareConfig(output=M, stdout=o[1], stderr=e[1])
+>>> import overlord;from overlord.api import OverlordAPI, create_fd;from overlord.config import BareConfig
+>>> e=create_fd();o=create_fd();from overlord.debug import Message;M=Message(module='overlord',out=o[1], err=e[1]);c=BareConfig(output=M, stdout=o[1], stderr=e[1])
>>> # connect the e[0] and o[0] file descriptors to where you want to capture/direct the output #
-...
+...
->>> l=LaymanAPI(config=c, output=M)
+>>> l=OverlordAPI(config=c, output=M)
>>> avail=l.get_available()
>>> avail
[u'DuPol', u'THE', u'akoya', u'alexcepoi', u'alexxy', u'amielke-overlay', u'anarchy', u'and3k-sunrise', u'arcon', u'armagetron', u'aross', u'bangert', u'bazaar', u'belak', u'benf', u'berkano', u'betagarden', u'betelgeuse', u'bibletime', u'calculate', u'cell', u'centerim', u'chtekk-apps', u'crg', u'd', u'dagger', u'dberkholz', u'deathwing00', u'dertobi123', u'desktop-effects', u'dev-zero', u'devnull', u'dilfridge', u'dirtyepic', u'dotnet', u'dottout', u'drizzt-overlay', u'eatnumber1', u'efika', u'emacs', u'embedded-cross', u'enlightenment', u'eva', u'eyolfson', u'falco', u'ferringb', u'finnish', u'flameeyes-overlay', u'foo-overlay', u'freevo', u'gamerlay', u'games', u'gcc-porting', u'gechi', u'genstef', u'gentoo-arm', u'gentoo-bsd', u'gentoo-china', u'gentoo-quebec', u'gentoo-taiwan', u'gentoojp', u'gnome', u'gnome-live', u'gnr', u'gnustep', u'gpe', u'graaff', u'halcy0n', u'hanno', u'hardened-development', u'haskell', u'hawking', u'hollow', u'hwoarang', u'iElectric', u'ibormuth', u'ikelos', u'init6', u'initng', u'interactive-fiction', u'iwlwifi', u'jasiu', u'java-overlay', u'je_fro', u'jensp', u'jmbsvicetto', u'jokey', u'jyujin', u'kde', u'kde-sunset', u'kerberos', u'keruspe', u'kolab', u'kvm', u'laurentb', u'leio', u'lila-theme', u'liquidx', u'lisp', u'loki_val', u'loongson', u'lordvan', u'lorelei', u'ltsp', u'lu_zero', u'luke-jr', u'lxde', u'm68k', u'maekke', u'maggu2810-overlay', u'mamona', u'marineam-xen', u'matsuu', u'mozilla', u'mpd', u'mrpouet', u'multilib', u'multimedia', u'mv', u'mysql', u'n4g', u'n4g-experimental', u'n8x0', u'nelchael', u'neurogeek', u'neuvoo', u'nirbheek', u'njw', u'nx', u'ohnobinki', u'openmoko', u'openoffice-geki', u'openrc', u'oss-overlay', u'otih', u'pchrist', u'pcsx2', u'pd-overlay', u'pda', u'pentoo', u'perl-experimental', u'php', u'php-4', u'piczu', u'pioto-overlay', u'plan9', u'portato', u'postgresql-experimental', u'postgresql-testing', u'powerman', u'powerpc', u'pro-audio', u'purak', u'pure-funtoo', u'python', u'pythonhead', u'qting-edge', u'rafaelmartins', u'ramereth', u'raw', u'rbu', u'remi', u'rion', u'robbat2', u'roslin', u'rostov', u'rox', u'rubenqba', u'ruby', u's3d', u'sabayon', u'sage-on-gentoo', u'sattvik', u'scarabeus', u'science', u'secondlife', u'seemant', u'serkan-overlay', u'sipx', u'sochotnicky', u'soor-overlay', u'sping', u'steev', u'stormfront', u'stuge', u'sugar', u'suka', u'sunrise', u'swegener', u'tante', u'tcl-8.6', u'tcl-multislot', u'thousand-parsec', u'toolchain', u'trapni', u'trauma', u'tryton', u'turbogears2', u'ub0rlay', u'vdr-devel', u'vdr-testing', u'vdr-xine', u'verlihub', u'vmware', u'voip', u'voyageur', u'vps', u'webapps-experimental', u'wirelay', u'wish', u'wolf31o2', u'wrobel', u'wschlich', u'wschlich-testing', u'x11', u'xemacs', u'xen', u'xfce-dev', u'xgr', u'xhub', u'xmms-zombie', u'xwing', u'zugaina']
@@ -43,7 +43,7 @@ True
True
>>> supported
True
->>>
+>>>
>>> results=l.get_info(['sunrise', 'sping'])
>>> len(results)
2
@@ -54,4 +54,4 @@ True
False
>>> supported
True
->>>
+>>>
diff --git a/bin/layman b/bin/lord
index 965d89b..128c672 100755
--- a/bin/layman
+++ b/bin/lord
@@ -1,6 +1,6 @@
#!/usr/bin/env python
################################################################################
-# LAYMAN - A UTILITY TO SELECT AND UPDATE GENTOO OVERLAYS
+# overlord - A UTILITY TO SELECT AND UPDATE GENTOO OVERLAYS
################################################################################
# Distributed under the terms of the GNU General Public License v2
#
@@ -24,8 +24,8 @@ __version__ = "$Id$"
#
#-------------------------------------------------------------------------------
-from layman.config import ArgsParser
-from layman.cli import Main
+from overlord.config import ArgsParser
+from overlord.cli import Main
#===============================================================================
#
diff --git a/doc/Makefile b/doc/Makefile
index 64b28af..0a4a6a1 100644
--- a/doc/Makefile
+++ b/doc/Makefile
@@ -1,5 +1,5 @@
#
-# layman/doc/Makefile
+# overlord/doc/Makefile
# Simple Makefile to rebuild the documentation from the
# docbook XML sources
#
@@ -12,10 +12,10 @@
#
# ========================================================================
-MAN_PAGES = layman.8
-HTML_PAGES = layman.8.html
+MAN_PAGES = overlord.8
+HTML_PAGES = overlord.8.html
-TMPFILE=./layman.man
+TMPFILE=./overlord.man
all: man html
diff --git a/doc/layman.8.xml b/doc/layman.8.xml
index dda55e9..319aeca 100644
--- a/doc/layman.8.xml
+++ b/doc/layman.8.xml
@@ -4,8 +4,8 @@
<article>
<articleinfo>
- <title>layman</title>
-
+ <title>overlord</title>
+
<authorgroup>
<author>
<firstname>Gunnar</firstname>
@@ -32,112 +32,112 @@
<itemizedlist>
<listitem>
<para>
- <link linkend="layman-synopsis">Synopsis</link>
+ <link linkend="overlord-synopsis">Synopsis</link>
</para>
</listitem>
</itemizedlist>
<itemizedlist>
<listitem>
<para>
- <link linkend="layman-description">Description</link>
+ <link linkend="overlord-description">Description</link>
</para>
</listitem>
</itemizedlist>
<itemizedlist>
<listitem>
<para>
- <link linkend="layman-actions">Action flags</link>
+ <link linkend="overlord-actions">Action flags</link>
</para>
</listitem>
</itemizedlist>
<itemizedlist>
<listitem>
<para>
- <link linkend="layman-other-options">Other options</link>
+ <link linkend="overlord-other-options">Other options</link>
</para>
</listitem>
</itemizedlist>
<itemizedlist>
<listitem>
<para>
- <link linkend="layman-configuration">Configuration</link>
+ <link linkend="overlord-configuration">Configuration</link>
</para>
</listitem>
</itemizedlist>
<itemizedlist>
<listitem>
<para>
- <link linkend="layman-remote">Overlay lists</link>
+ <link linkend="overlord-remote">Overlay lists</link>
</para>
</listitem>
</itemizedlist>
<itemizedlist>
<listitem>
<para>
- <link linkend="layman-local">Layman cache</link>
+ <link linkend="overlord-local">overlord cache</link>
</para>
</listitem>
</itemizedlist>
<itemizedlist>
<listitem>
<para>
- <link linkend="layman-make-conf">Handling make.conf</link>
+ <link linkend="overlord-make-conf">Handling make.conf</link>
</para>
</listitem>
</itemizedlist>
<itemizedlist>
<listitem>
<para>
- <link linkend="layman-update">Handle overlays</link>
+ <link linkend="overlord-update">Handle overlays</link>
</para>
</listitem>
</itemizedlist>
<itemizedlist>
<listitem>
<para>
- <link linkend="layman-list">List overlays</link>
+ <link linkend="overlord-list">List overlays</link>
</para>
</listitem>
</itemizedlist>
<itemizedlist>
<listitem>
<para>
- <link linkend="layman-search">Searching ebuilds in overlays</link>
+ <link linkend="overlord-search">Searching ebuilds in overlays</link>
</para>
</listitem>
</itemizedlist>
<itemizedlist>
<listitem>
<para>
- <link linkend="layman-types">Overlay types</link>
+ <link linkend="overlord-types">Overlay types</link>
</para>
</listitem>
</itemizedlist>
<itemizedlist>
<listitem>
<para>
- <link linkend="layman-global">Get your overlay published to the world</link>
+ <link linkend="overlord-global">Get your overlay published to the world</link>
</para>
</listitem>
</itemizedlist>
<itemizedlist>
<listitem>
<para>
- <link linkend="layman-examples">Examples</link>
+ <link linkend="overlord-examples">Examples</link>
</para>
</listitem>
</itemizedlist>
<itemizedlist>
<listitem>
<para>
- <link linkend="layman-files">Layman files</link>
+ <link linkend="overlord-files">Overlord files</link>
</para>
</listitem>
</itemizedlist>
<itemizedlist>
<listitem>
<para>
- <link linkend="layman-bugs">Reporting bugs</link>
+ <link linkend="overlord-bugs">Reporting bugs</link>
</para>
</listitem>
</itemizedlist>
@@ -148,7 +148,7 @@
<itemizedlist>
<listitem>
<para>
- <ulink url="http://sourceforge.net/projects/layman/">Layman project page on SourceForge</ulink>
+ <ulink url="http://sourceforge.net/projects/layman/">overlord project page on SourceForge</ulink>
</para>
</listitem>
<listitem>
@@ -189,14 +189,14 @@
</itemizedlist>
</section>
- <section id="layman-reference">
+ <section id="overlord-reference">
<title>Reference</title>
- <refentry id="layman-manpage">
+ <refentry id="overlord-manpage">
<refentryinfo>
- <title>layman</title>
+ <title>overlord</title>
<date>July 2010</date>
- <productname>layman</productname>
+ <productname>overlord</productname>
<productnumber>1.4.1</productnumber>
<copyright>
<year>2005-2009</year>
@@ -211,19 +211,19 @@
</legalnotice>
</refentryinfo>
<refmeta>
- <refentrytitle>layman</refentrytitle>
+ <refentrytitle>overlord</refentrytitle>
<manvolnum>8</manvolnum>
</refmeta>
<refnamediv>
- <refname>layman</refname>
+ <refname>overlord</refname>
<refpurpose>
manage your local repository of Gentoo overlays
</refpurpose>
</refnamediv>
- <refsynopsisdiv id="layman-synopsis">
+ <refsynopsisdiv id="overlord-synopsis">
<cmdsynopsis>
- <command>layman</command>
+ <command>overlord</command>
<group choice="plain">
<arg>-a</arg>
<arg>--add</arg>
@@ -235,7 +235,7 @@
</cmdsynopsis>
<cmdsynopsis>
- <command>layman</command>
+ <command>overlord</command>
<group choice="plain">
<arg>-d</arg>
<arg>--delete</arg>
@@ -247,7 +247,7 @@
</cmdsynopsis>
<cmdsynopsis>
- <command>layman</command>
+ <command>overlord</command>
<group choice="plain">
<arg>-s</arg>
<arg>--sync</arg>
@@ -259,7 +259,7 @@
</cmdsynopsis>
<cmdsynopsis>
- <command>layman</command>
+ <command>overlord</command>
<group choice="plain">
<arg>-i</arg>
<arg>--info</arg>
@@ -271,7 +271,7 @@
</cmdsynopsis>
<cmdsynopsis>
- <command>layman</command>
+ <command>overlord</command>
<group choice="plain">
<arg>-S</arg>
<arg>--sync-all</arg>
@@ -279,7 +279,7 @@
</cmdsynopsis>
<cmdsynopsis>
- <command>layman</command>
+ <command>overlord</command>
<group choice="plain">
<arg>-L</arg>
<arg>--list</arg>
@@ -287,7 +287,7 @@
</cmdsynopsis>
<cmdsynopsis>
- <command>layman</command>
+ <command>overlord</command>
<group choice="plain">
<arg>-l</arg>
<arg>--list-local</arg>
@@ -295,7 +295,7 @@
</cmdsynopsis>
<cmdsynopsis>
- <command>layman</command>
+ <command>overlord</command>
<group choice="plain">
<arg>-f</arg>
<arg>--fetch</arg>
@@ -304,45 +304,45 @@
</refsynopsisdiv>
- <refsection id="layman-description">
+ <refsection id="overlord-description">
<title>Description</title>
- <para><command>layman</command> is a script that allows you to
+ <para><command>overlord</command> is a script that allows you to
add, remove and update Gentoo overlays from a variety of
sources.</para>
<refsection>
<title>WARNING</title>
- <para><command>layman</command> makes it easy to retrieve and
+ <para><command>overlord</command> makes it easy to retrieve and
update overlays for Gentoo. In addition it makes it TRIVIAL
- to break your system.
+ to break your system.
</para>
<para>The main portage tree provides you with high quality ebuilds
that are all maintained by Gentoo developers. This will not
be the case for most of the overlays you can get by using
- <command>layman</command>. Thus you are removing the
+ <command>overlord</command>. Thus you are removing the
security shield that the standard tree provides for
you. You should keep that in mind when installing ebuilds
from an overlay.
</para>
<para>To ensure the security of your system you MUST read the
- source of the ebuild you are about to install.
+ source of the ebuild you are about to install.
</para>
</refsection>
</refsection>
- <refsection id="layman-options">
+ <refsection id="overlord-options">
<title>Options</title>
- <refsection id="layman-actions">
+ <refsection id="overlord-actions">
<title>Actions</title>
- <para>List of possible <command>layman</command> actions.</para>
+ <para>List of possible <command>overlord</command> actions.</para>
<variablelist>
<varlistentry>
@@ -420,11 +420,11 @@
</variablelist>
</refsection>
- <refsection id="layman-other-options">
+ <refsection id="overlord-other-options">
<title>Other options</title>
- <para>List of other available <command>layman</command> options.</para>
+ <para>List of other available <command>overlord</command> options.</para>
<variablelist>
@@ -446,7 +446,7 @@
of URLs you specified in your config file. You may also
specify local file URLs by prepending the path with
<userinput>file://</userinput>. This option
- will only append the URL for this specific layman run -
+ will only append the URL for this specific overlord run -
edit your config file to add a URL permanently. So this
is useful for testing purposes.
</para>
@@ -457,9 +457,9 @@
<term><option>-n</option></term>
<term><option>--nofetch</option></term>
<listitem>
- <para>Prevents <command>layman</command> from
+ <para>Prevents <command>overlord</command> from
automatically fetching the remote lists of overlays. The
- default behavior for <command>layman</command> is to
+ default behavior for <command>overlord</command> is to
update all remote lists if you run the sync, list or
fetch operation.</para>
</listitem>
@@ -469,9 +469,9 @@
<term><option>-k</option></term>
<term><option>--nocheck</option></term>
<listitem>
- <para>Prevents <command>layman</command> from checking
+ <para>Prevents <command>overlord</command> from checking
the remote lists of overlays for complete overlay
- definitions. The default behavior for layman is to
+ definitions. The default behavior for overlord is to
reject overlays that do not provide a description or a
contact attribute.</para>
</listitem>
@@ -481,7 +481,7 @@
<term><option>-q</option></term>
<term><option>--quiet</option></term>
<listitem>
- <para>Makes <command>layman</command> completely quiet.
+ <para>Makes <command>overlord</command> completely quiet.
In quiet mode child processes will be run with stdin closed
to avoid running into infinite and blindly interactive sessions.
Thus a child process may abort once it runs into an
@@ -496,7 +496,7 @@
<term><option>-v</option></term>
<term><option>--verbose</option></term>
<listitem>
- <para>Makes <command>layman</command> more verbose and
+ <para>Makes <command>overlord</command> more verbose and
you will receive a description of the overlays you can
download.</para>
</listitem>
@@ -506,7 +506,7 @@
<term><option>-N</option></term>
<term><option>--nocolor</option></term>
<listitem>
- <para>Remove color codes from the <command>layman</command>
+ <para>Remove color codes from the <command>overlord</command>
output.</para>
</listitem>
</varlistentry>
@@ -515,7 +515,7 @@
<term><option>-Q</option><replaceable>LEVEL</replaceable></term>
<term><option>--quietness</option><replaceable>LEVEL</replaceable></term>
<listitem>
- <para>Makes <command>layman</command> less verbose.
+ <para>Makes <command>overlord</command> less verbose.
Choose a value between 0 and 4 with 0 being completely
quiet. Once you set this below 3, the same warning as
given for --quiet applies.</para>
@@ -542,13 +542,13 @@
</refsection>
- <refsection id="layman-configuration">
+ <refsection id="overlord-configuration">
<title>Configuration</title>
- <para><command>layman</command> reads configuration parameters
+ <para><command>overlord</command> reads configuration parameters
from the file
- <filename>/etc/layman/layman.cfg</filename> by
+ <filename>/etc/overlord/overlord.cfg</filename> by
default. This file provides seven possible settings.</para>
<variablelist>
@@ -557,16 +557,16 @@
<term><option>storage</option></term>
<listitem>
<para>Directory that will be used to store the overlays
- and all additional data <command>layman</command>
+ and all additional data <command>overlord</command>
needs. The default is
- <filename>/var/lib/layman</filename>. layman
+ <filename>/var/lib/layman</filename>. overlord
uses a location within the /usr/portage hierarchy instead
of <filename>/var</filename> in order to
store its data. This decision has been made to support
network file systems. If you have your portage tree on nfs
or a similar file system and several machines access the
same ebuild repository over the net it will be necessary
- to also provide all necessary <command>layman</command>
+ to also provide all necessary <command>overlord</command>
data within the hierarchy of the tree. This way the
overlays will also have to be synced at one location
only.</para>
@@ -576,7 +576,7 @@
<varlistentry>
<term><option>cache</option></term>
<listitem>
- <para><command>layman</command> will store the downloaded
+ <para><command>overlord</command> will store the downloaded
global list of overlays here. The default is
<filename>%(storage)s/cache.xml</filename>.</para>
</listitem>
@@ -585,7 +585,7 @@
<varlistentry>
<term><option>overlays</option></term>
<listitem>
- <para><command>layman</command> will store the list of
+ <para><command>overlord</command> will store the list of
installed overlays here. The default is
<filename>%(storage)s/overlays.xml</filename>.</para>
</listitem>
@@ -595,7 +595,7 @@
<term><option>make.conf</option></term>
<listitem>
<para>This is the portage configuration file that
- <command>layman</command> will modify in order to make
+ <command>overlord</command> will modify in order to make
the new overlays available within portage. The default
is <filename>%(storage)s/make.conf</filename>. You could
also specify <filename>/etc/make.conf
@@ -606,7 +606,7 @@
very small external file that only contains the setting
for PORTAGE_OVERLAYS. This file is then sourced at the
end of <filename>/etc/make.conf</filename>. This is the
- reason why <command>layman</command> suggests running
+ reason why <command>overlord</command> suggests running
"echo "source
<filename>/var/lib/layman/make.conf</filename>" >>
<filename>/etc/make.conf</filename>" after it has been
@@ -638,7 +638,7 @@
<varlistentry>
<term><option>nocheck</option></term>
<listitem>
- <para>Set to "yes" if <command>layman</command> should stop
+ <para>Set to "yes" if <command>overlord</command> should stop
worrying about overlays with missing a contact address or
the description.</para>
</listitem>
@@ -648,19 +648,19 @@
</refsection>
- <refsection id="layman-handling">
+ <refsection id="overlord-handling">
<title>Handling overlays</title>
- <para><command>layman</command> intends to provide easy
+ <para><command>overlord</command> intends to provide easy
maintenance of Gentoo overlays while not requiring any
configuration.
</para>
- <refsection id="layman-remote">
+ <refsection id="overlord-remote">
<title>Overlay lists</title>
- <para><command>layman</command> allows you to fetch an
+ <para><command>overlord</command> allows you to fetch an
overlay without the need to modify any configuration
files. In order for this to be possible the script needs an
external list of possible overlay sources. There is a
@@ -669,11 +669,11 @@
but nothing will prevent you from using or publishing your
own list of overlays. The location of the remote lists can
also be modified using the <option>--overlays</option>
- option when running <command>layman</command>.
+ option when running <command>overlord</command>.
</para>
<para>To get a new overlay added to the central list provided
- for layman, send a mail to
+ for overlord, send a mail to
<email>overlays@gentoo.org</email>. Gentoo developers may
add their overlay entries directly into the list which can
be accessed over the CVS repository for the Gentoo
@@ -682,11 +682,11 @@
<para>You can also use several lists at the same time. Just
add one URL per line to the overlays variable in your
- configuration file. <command>layman</command> will merge the
- contents of all lists.
+ configuration file. <command>overlord</command> will merge the
+ contents of all lists.
</para>
- <para><command>layman</command> also allows you to define
+ <para><command>overlord</command> also allows you to define
local files in this list. Just make sure you prepend these
path names in standard URL notation
with <filename>file://</filename>.
@@ -694,32 +694,32 @@
<para>If you need to use a proxy for access to the Internet,
you can use the corresponding variable in
- the <command>layman</command> configuration file. Layman
+ the <command>overlord</command> configuration file. overlord
will also respect the <command>http_proxy</command>
environment variable in case you set it.
</para>
</refsection>
- <refsection id="layman-local">
+ <refsection id="overlord-local">
<title>Local cache</title>
- <para><command>layman</command> stores a local copy of the
+ <para><command>overlord</command> stores a local copy of the
fetched remote list. It will be stored in
<filename>/var/lib/layman/cache.xml</filename>
by default. There exists only one such cache file and it
will be overwritten every time you
- run <command>layman</command>.
+ run <command>overlord</command>.
</para>
</refsection>
- <refsection id="layman-make-conf">
+ <refsection id="overlord-make-conf">
<title>Handling <filename>/etc/make.conf</filename></title>
- <para>Since <command>layman</command> is designed to
+ <para>Since <command>overlord</command> is designed to
automatically handle the inclusion of overlays into your
system it needs to be able to modify
the <command>PORTDIR_OVERLAY</command> variable in your
@@ -728,72 +728,72 @@
essential configuration file for a Gentoo
system. Automatically modifying this file would be
somewhat dangerous. You can
- allow <command>layman</command> to do this by setting
+ allow <command>overlord</command> to do this by setting
the <command>make_conf</command> variable in the
configuration file to <filename>/etc/make.conf</filename>.
</para>
<para>A much safer and in fact recommended solution to the
- problem is to let <command>layman</command> handle an
+ problem is to let <command>overlord</command> handle an
external file that only contains
the <command>PORTDIR_OVERLAY</command> variable and is
sourced within the
- standard <filename>/etc/make.conf</filename> file. Just add the following line to the end of your
+ standard <filename>/etc/make.conf</filename> file. Just add the following line to the end of your
<filename>/etc/make.conf</filename> file:
</para>
<para>source /var/lib/layman/make.conf</para>
<para><filename>/var/lib/layman/make.conf</filename>
- is the default provided in the layman
+ is the default provided in the overlord
configuration. Change this file name in case you decide to
store it somewhere else.
</para>
<para>The file does not necessarily need to exist at the
- beginning. If it is missing, layman will create it for you.
+ beginning. If it is missing, overlord will create it for you.
</para>
<para>There is also no need to remove the
original <command>PORTDIR_OVERLAY</command> variable from
- the make.conf file. Layman will simply add new overlays to
+ the make.conf file. overlord will simply add new overlays to
this variable and all your old entries will remain in there.
</para>
</refsection>
- <refsection id="layman-update">
+ <refsection id="overlord-update">
<title>Adding, removing and updating overlays</title>
<para>Once a remote list of overlays has been fetched,
- <command>layman</command> allows to add overlays from the
+ <command>overlord</command> allows to add overlays from the
remote list to your system. The script will try to fetch
the overlay. If this is successful the overlay information
will be copied from the cache to the list of locally
installed overlays. In addition
- <command>layman</command> will modify the
+ <command>overlord</command> will modify the
<command>PORTDIR_OVERLAY</command> variable to include the
new overlay path.
</para>
- <para>Removing the overlay with <command>layman</command> will
+ <para>Removing the overlay with <command>overlord</command> will
delete the overlay without leaving any traces behind.
</para>
<para>In order to update all overlays managed by
- <command>layman</command> you can run the script with the
+ <command>overlord</command> you can run the script with the
<option>--sync ALL</option> option or
the <option>--sync-all</option> flag.
</para>
</refsection>
- <refsection id="layman-list">
+ <refsection id="overlord-list">
<title>List overlays</title>
- <para><command>layman</command> provides the
+ <para><command>overlord</command> provides the
<option>--list</option> and <option>--list-local</option>
options to print a list of available respectively
installed overlays.
@@ -806,19 +806,19 @@
with a red asterisk.
</para>
- <para> In the default mode layman will be strict about
+ <para> In the default mode overlord will be strict about
listing overlays and only present you with overlays that
are fully supported. In addition it will complain about
overlays that are missing a description field or a contact
attribute. This type of behavior has been added with
- layman-1.0.7 and if you'd like to return to the old
+ overlord-1.0.7 and if you'd like to return to the old
behavior you may use the k option flag or set the nocheck
option in the configuration file.
</para>
</refsection>
- <refsection id="layman-search">
+ <refsection id="overlord-search">
<title>Searching ebuilds in overlays</title>
@@ -831,14 +831,14 @@
</refsection>
- <refsection id="layman-types">
+ <refsection id="overlord-types">
<title>Overlay types</title>
- <para>Currently <command>layman</command> supports overlays that
+ <para>Currently <command>overlord</command> supports overlays that
are exported via <command>rsync</command>,
- <command>subversion</command>, <command>bzr</command>,
- <command>darcs</command>, <command>git</command>,
+ <command>subversion</command>, <command>bzr</command>,
+ <command>darcs</command>, <command>git</command>,
<command>mercurial</command> or provided
as <command>tar</command> packages.
</para>
@@ -847,7 +847,7 @@
</refsection>
- <refsection id="layman-global">
+ <refsection id="overlord-global">
<title>Overlay lists</title>
@@ -856,7 +856,7 @@
<title>Overlay list format</title>
<para>
- Layman uses a central list of overlays in XML format. The file looks like this:
+ overlord uses a central list of overlays in XML format. The file looks like this:
<example>
<title>An example overlays.xml file</title>
<programlisting>
@@ -890,7 +890,7 @@
<para>
Simply create an overlay list in the format described
- above and run <command>layman</command> with the
+ above and run <command>overlord</command> with the
<option>-o</option> switch. You need to
prepend local file URLs with
<userinput>file://</userinput>.
@@ -904,7 +904,7 @@
<para>
The global list of overlays used by
- <command>layman</command> lies at
+ <command>overlord</command> lies at
<filename>http://www.gentoo.org/proj/en/overlays/repositories.xml</filename>.
</para>
@@ -925,7 +925,7 @@
</refsection>
- <refsection id="layman-examples">
+ <refsection id="overlord-examples">
<title>Examples</title>
@@ -933,7 +933,7 @@
<title>Installing an overlay</title>
- <para><userinput>layman -f -a wrobel</userinput></para>
+ <para><userinput>overlord -f -a wrobel</userinput></para>
<para>This would add the overlay with the id
<command>wrobel</command> to your list of installed
overlays.</para>
@@ -944,7 +944,7 @@
<title>Syncing your overlays</title>
- <para><userinput>layman -s ALL</userinput></para>
+ <para><userinput>overlord -s ALL</userinput></para>
<para>This updates all overlays</para>
</refsection>
@@ -953,7 +953,7 @@
<title>Performing several actions at the same time</title>
- <para><userinput>layman -f -a wrobel -a webapps-experimental</userinput></para>
+ <para><userinput>overlord -f -a wrobel -a webapps-experimental</userinput></para>
<para>This fetches the remote list and immediately adds two
overlays</para>
@@ -961,7 +961,7 @@
</refsection>
- <refsection id="layman-files">
+ <refsection id="overlord-files">
<title>Files</title>
@@ -982,7 +982,7 @@
<refsection id="layman-bugs">
<title>Reporting bugs</title>
-
+
<para>
Please report bugs you might find at <ulink url="http://bugs.gentoo.org"/>
</para>
diff --git a/etc/cache.xml b/etc/cache.xml
index 2f4759d..8c3d7d2 100644
--- a/etc/cache.xml
+++ b/etc/cache.xml
@@ -1,5 +1,5 @@
<?xml version="1.0" ?>
-<layman>
+<overlord>
<overlay
type = "svn"
@@ -52,7 +52,7 @@
aim is to increase the rate of development of scientific
packages for Gentoo, but ebuilds in this repository are by their
very nature more experimental. If you wish to use them you
- should be willing to help test and report bugs.
+ should be willing to help test and report bugs.
</description>
</overlay>
@@ -172,7 +172,7 @@
name = "ebuild-exchange">
<link>
- http://www.ebuildexchange.org/
+ http://www.ebuildexchange.org/
</link>
<description>
@@ -211,7 +211,7 @@
<description>
Portage Overlay tree of new gentoo based distibution called
Fantoo Linux. Fantoo Linux aims to be bleeding edge and bugfixes
- in gentoo upstream.
+ in gentoo upstream.
</description>
</overlay>
@@ -323,9 +323,9 @@
</link>
<description>
- A series of unsupported multimedia ebuilds for Gentoo
- portage that are either updated versions, live CVS/SVN
- packages, or have updated features not included in the
+ A series of unsupported multimedia ebuilds for Gentoo
+ portage that are either updated versions, live CVS/SVN
+ packages, or have updated features not included in the
official portage tree.
</description>
@@ -357,7 +357,7 @@
category = "sys-libs">
<link>
- http://forums.gentoo.org/viewtopic-t-435659-start-0-postdays-0-postorder-asc-highlight-nxsty+glibc.html
+ http://forums.gentoo.org/viewtopic-t-435659-start-0-postdays-0-postorder-asc-highlight-nxsty+glibc.html
</link>
<description>
@@ -373,7 +373,7 @@
category = "sys-devel">
<link>
- http://forums.gentoo.org/viewtopic-t-435659-start-0-postdays-0-postorder-asc-highlight-nxsty+glibc.html
+ http://forums.gentoo.org/viewtopic-t-435659-start-0-postdays-0-postorder-asc-highlight-nxsty+glibc.html
</link>
<description>
@@ -392,7 +392,7 @@
</link>
<description>
- Overlay for the NX/FreeNX packages for Gentoo.
+ Overlay for the NX/FreeNX packages for Gentoo.
</description>
</overlay>
@@ -495,37 +495,37 @@
</overlay>
- <overlay
+ <overlay
type = "svn"
name = "liferea_overlay"
src = "https://82.224.45.203/svn/liferea_overlay" >
-
+
<link>
http://liferea.sourceforge.net/
</link>
-
+
<description>
Updated ebuilds for newer versions of Liferea
</description>
-
+
</overlay>
- <overlay
+ <overlay
type = "svn"
name = "yao"
src = "svn://svn.berlios.de/yao/trunk" >
-
+
<link>
http://developer.berlios.de/projects/yao/
</link>
-
+
<description>
Yet Another Overlay aims to provide ebuilds for light
applications to allow Gentoo users to maintain a light desktop
without being restricted to the small amount of apps which don't
depend on GNOME or KDE libraries.
</description>
-
+
</overlay>
-</layman>
+</overlord>
diff --git a/etc/layman.cfg b/etc/layman.cfg
index b45c6f0..4a1a40d 100644
--- a/etc/layman.cfg
+++ b/etc/layman.cfg
@@ -7,7 +7,7 @@ storage : /var/lib/layman
#-----------------------------------------------------------
# Remote overlay lists will be stored here
-# layman will append _md5(url).xml to each filename
+# overlord will append _md5(url).xml to each filename
cache : %(storage)s/cache
@@ -17,33 +17,33 @@ cache : %(storage)s/cache
local_list: %(storage)s/overlays.xml
#-----------------------------------------------------------
-# Path to the make.conf file that should be modified by
-# layman
+# Path to the make.conf file that should be modified by
+# overlord
make_conf : %(storage)s/make.conf
#-----------------------------------------------------------
-# URLs of the remote lists of overlays (one per line) or
+# URLs of the remote lists of overlays (one per line) or
# local overlay definitions
#
#overlays : http://www.gentoo.org/proj/en/overlays/repositories.xml
# http://dev.gentoo.org/~wrobel/layman/global-overlays.xml
-# http://mydomain.org/my-layman-list.xml
+# http://mydomain.org/my-overlord-list.xml
# file:///var/lib/layman/my-list.xml
overlays : http://www.gentoo.org/proj/en/overlays/repositories.xml
#-----------------------------------------------------------
# Proxy support
-# If unset, layman will use the http_proxy environment variable.
+# If unset, overlord will use the http_proxy environment variable.
#
#proxy : http://[user:pass@]www.my-proxy.org:3128
#-----------------------------------------------------------
# Strict checking of overlay definitions
#
-# Set either to "yes" or "no". If "no" layman will issue
-# warnings if an overlay definition is missing either
+# Set either to "yes" or "no". If "no" overlord will issue
+# warnings if an overlay definition is missing either
# description or contact information.
#
nocheck : yes
@@ -51,7 +51,7 @@ nocheck : yes
#-----------------------------------------------------------
# Umask settings
#
-# layman should usually work with a umask of 0022. You should
+# overlord should usually work with a umask of 0022. You should
# only change this setting if you are absolutely certain that
# you know what you are doing.
#
diff --git a/layman/.svn.ignore b/layman/.svn.ignore
deleted file mode 100644
index 0d20b64..0000000
--- a/layman/.svn.ignore
+++ /dev/null
@@ -1 +0,0 @@
-*.pyc
diff --git a/layman/overlays/.svn.ignore b/layman/overlays/.svn.ignore
deleted file mode 100644
index 0d20b64..0000000
--- a/layman/overlays/.svn.ignore
+++ /dev/null
@@ -1 +0,0 @@
-*.pyc
diff --git a/layman/__init__.py b/overlord/__init__.py
index 792d600..792d600 100644
--- a/layman/__init__.py
+++ b/overlord/__init__.py
diff --git a/layman/makeconf.py b/overlord/makeconf.py
index fdd10c4..4906d0a 100644
--- a/layman/makeconf.py
+++ b/overlord/makeconf.py
@@ -19,7 +19,7 @@ import os
import codecs
import re
-from layman.utils import path
+from overlord.utils import path
#===============================================================================
#
diff --git a/layman/overlays/__init__.py b/overlord/overlays/__init__.py
index 792d600..792d600 100644
--- a/layman/overlays/__init__.py
+++ b/overlord/overlays/__init__.py
diff --git a/layman/tests/pylintrc b/overlord/tests/pylintrc
index b05498a..b05498a 100644
--- a/layman/tests/pylintrc
+++ b/overlord/tests/pylintrc
diff --git a/layman/tests/testfiles/global-overlays.xml b/overlord/tests/testfiles/global-overlays.xml
index d770692..d770692 100644
--- a/layman/tests/testfiles/global-overlays.xml
+++ b/overlord/tests/testfiles/global-overlays.xml
diff --git a/layman/tests/testfiles/layman-test.tar.bz2 b/overlord/tests/testfiles/layman-test.tar.bz2
index 85ee7fd..85ee7fd 100644
--- a/layman/tests/testfiles/layman-test.tar.bz2
+++ b/overlord/tests/testfiles/layman-test.tar.bz2
Binary files differ
diff --git a/layman/tests/testfiles/make.conf b/overlord/tests/testfiles/make.conf
index 9a8aac6..9a8aac6 100644
--- a/layman/tests/testfiles/make.conf
+++ b/overlord/tests/testfiles/make.conf
diff --git a/layman/tests/testfiles/overlays_bug_184449.xml b/overlord/tests/testfiles/overlays_bug_184449.xml
index c8dff2d..c8dff2d 100644
--- a/layman/tests/testfiles/overlays_bug_184449.xml
+++ b/overlord/tests/testfiles/overlays_bug_184449.xml
diff --git a/layman/tests/testfiles/overlays_bug_286290.xml b/overlord/tests/testfiles/overlays_bug_286290.xml
index 1d4bd1b..1d4bd1b 100644
--- a/layman/tests/testfiles/overlays_bug_286290.xml
+++ b/overlord/tests/testfiles/overlays_bug_286290.xml
diff --git a/layman/tests/testfiles/subpath-1.xml b/overlord/tests/testfiles/subpath-1.xml
index ddb0e3e..ddb0e3e 100644
--- a/layman/tests/testfiles/subpath-1.xml
+++ b/overlord/tests/testfiles/subpath-1.xml
diff --git a/layman/tests/testfiles/subpath-2.xml b/overlord/tests/testfiles/subpath-2.xml
index aa11497..aa11497 100644
--- a/layman/tests/testfiles/subpath-2.xml
+++ b/overlord/tests/testfiles/subpath-2.xml
diff --git a/layman/utils.py b/overlord/utils.py
index 67a0ab7..c5a2019 100644
--- a/layman/utils.py
+++ b/overlord/utils.py
@@ -34,7 +34,7 @@ import sys
import locale
import codecs
-from layman.debug import OUT
+from overlord.debug import OUT
#===============================================================================
diff --git a/layman/version.py b/overlord/version.py
index ea6757f..abbea1a 100644
--- a/layman/version.py
+++ b/overlord/version.py
@@ -1,7 +1,7 @@
#!/usr/bin/python
# -*- coding: utf-8 -*-
#################################################################################
-# LAYMAN VERSION
+# overlord VERSION
#################################################################################
# File: version.py
#
diff --git a/setup.py b/setup.py
index 9c50c54..75765cd 100755
--- a/setup.py
+++ b/setup.py
@@ -9,13 +9,13 @@ sys.path.insert(0, './')
from layman.version import VERSION
-setup(name = 'layman',
- version = VERSION,
- description = 'Python script for retrieving gentoo overlays',
- author = 'Gunnar Wrobel',
- author_email = 'wrobel@gentoo.org',
- url = 'http://projects.gunnarwrobel.de/scripts',
- packages = ['layman', 'layman.overlays'],
- scripts = ['bin/layman'],
- license = 'GPL',
- )
+setup(name = 'overlord',
+ version = VERSION,
+ description = 'Python script and libraries for retrieving gentoo overlays',
+ author = 'Brian Dolbec',
+ author_email = 'brian.dolbec@gmail.com',
+ url = 'http://',
+ packages = ['overlord', 'overlord.overlays'],
+ scripts = ['bin/lord'],
+ license = 'GPL',
+ )
diff --git a/testsuite.sh b/testsuite.sh
index ce125d2..eb210aa 100755
--- a/testsuite.sh
+++ b/testsuite.sh
@@ -1,9 +1,14 @@
#!/usr/bin/env bash
-# Copyright (C) 2010 Sebastian Pipping <sebastian@pipping.org>
+
+#
+# Copyright (C) 2010 Sebastian Pipping <sebastian@pipping.org>
+# 2011 Brian Dolbec <brian.dolbec@gmail.com>
+#
# Licensed under GPLv2
+
ret=0
-for script in layman/tests/*.py ; do
+for script in overlord/tests/*.py ; do
echo "# PYTHONPATH=\"${PWD}\" python \"${script}\""
PYTHONPATH="${PWD}" python "${script}" \
|| ret=1
diff --git a/layman/api.py b/overlord/api.py
index da39d49..936af9b 100644
--- a/layman/api.py
+++ b/overlord/api.py
@@ -1,28 +1,29 @@
#!python
# -*- coding: utf-8 -*-
-#######################################################################
-# LAYMAN - A UTILITY TO SELECT AND UPDATE GENTOO OVERLAYS
-#######################################################################
-# Distributed under the terms of the GNU General Public License v2
-#
-# Copyright:
-# (c) 2010 Brian Dolbec
-# Distributed under the terms of the GNU General Public License v2
-#
-# Author(s):
-# Brian Dolbec <dol-sen@sourceforge.net>
-#
+
+"""
+ Overlord - A UTILITY TO SELECT AND UPDATE GENTOO OVERLAYS
+ Distributed under the terms of the GNU General Public License v2
+
+ Copyright:
+ (c) 2010 - 2011 Brian Dolbec
+ Distributed under the terms of the GNU General Public License v2
+
+ Author(s):
+ Brian Dolbec <dol-sen@sourceforge.net>
+
+"""
from sys import stderr
import os
-from layman.config import BareConfig
-#from layman.action import Sync
+from overlord.config import BareConfig
+#from overlord.action import Sync
-from layman.dbbase import UnknownOverlayException
-from layman.db import DB, RemoteDB
-#from layman.utils import path, delete_empty_directory
-from layman.debug import OUT
+from overlord.dbbase import UnknownOverlayException
+from overlord.db import DB, RemoteDB
+#from overlord.utils import path, delete_empty_directory
+from overlord.debug import OUT
# give them some values for now, these are from the packagekit backend
# TODO establish some proper errors for the api.
@@ -33,15 +34,14 @@ UNKNOWN_REPO_ID = "Repo ID '%s' " + \
# In order to redirect output you need to get a Message class instance with the
# stderr, stdout, stddebug directed to where you want.
-# eg: output = Message('layman', err=mystderr, dbg=mydebug, out=myoutput)
+# eg: output = Message('overlord', err=mystderr, dbg=mydebug, out=myoutput)
# there are many more options available, refer to debug.py Message class
-class LaymanAPI(object):
- """class to hold and run a layman instance for use by API consumer apps, guis, etc.
+class OverlordAPI(object):
+ """High level class to hold and run a overlord instance for use by
+ API consumer apps, guis, etc.
"""
- ## hell, even the current cli should probably be converted to use this one.
- ## It is a near duplicate of the actions classes.
def __init__(self, config=None, report_errors=False, output=None):
"""
@@ -51,7 +51,7 @@ class LaymanAPI(object):
@param report_errors: optional bool to silence some error reporting to stdout
default is False
@param output: optional Message class instance created with your settings.
- default is Message(module='layman') other params are defaults.
+ default is Message(module='overlord') other params are defaults.
"""
self.output = output if output else OUT
diff --git a/layman/cli.py b/overlord/cli.py
index 0921223..501dd65 100644
--- a/layman/cli.py
+++ b/overlord/cli.py
@@ -1,11 +1,11 @@
#!/usr/bin/python
# -*- coding: utf-8 -*-
#################################################################################
-# LAYMAN ACTIONS
+# overlord ACTIONS
#################################################################################
# File: cli.py
#
# Handles layman actions via the command line interface.
#
# Copyright:
# (c) 2010 - 2011
@@ -17,17 +17,17 @@
# Gunnar Wrobel <wrobel@gentoo.org>
# Brian Dolbec <brian.dolbec@gmail.com
#
-''' Provides the command line actions that can be performed by layman.'''
+''' Provides the command line actions that can be performed by overlord.'''
__version__ = "$Id: cli.py 2011-01-15 23:52 PST Brian Dolbec$"
import os, sys
-from layman.api import LaymanAPI
-from layman.utils import (decode_selection, encoder, get_encoding,
+from overlord.api import OverlordAPI
+from overlord.utils import (decode_selection, encoder, get_encoding,
pad, terminal_width)
-from layman.constants import NOT_OFFICIAL_MSG, NOT_SUPPORTED_MSG
+from overlord.constants import NOT_OFFICIAL_MSG, NOT_SUPPORTED_MSG
@@ -128,7 +128,7 @@ class Main(object):
self.config = config
#print "config.keys()", config.keys()
self.output = config['output']
- self.api = LaymanAPI(config,
+ self.api = OverlordAPI(config,
report_errors=True,
output=config.output)
# Given in order of precedence
@@ -1,11 +1,11 @@
# File: cli.py
#
-# Handles layman actions via the command line interface.
+# Handles overlord actions via the command line interface.
#
# Copyright:
diff --git a/layman/config.py b/overlord/config.py
index baa3af3..4caf83c 100644
--- a/layman/config.py
+++ b/overlord/config.py
@@ -1,11 +1,11 @@
#!/usr/bin/python
# -*- coding: utf-8 -*-
#################################################################################
-# LAYMAN CONFIGURATION
+# overlord CONFIGURATION
#################################################################################
# File: config.py
#
# Handles layman configuration
#
# Copyright:
# (c) 2005 - 2009 Gunnar Wrobel
@@ -30,8 +30,8 @@ __version__ = "$Id: config.py 286 2007-01-09 17:48:23Z wrobel $"
import sys, ConfigParser
from optparse import OptionParser, OptionGroup
-from layman.debug import OUT
-from layman.version import VERSION
+from overlord.debug import OUT
+from overlord.version import VERSION
#===============================================================================
#
@@ -40,9 +40,9 @@ from layman.version import VERSION
#-------------------------------------------------------------------------------
_USAGE = """
- layman (-a|-d|-s|-i) (OVERLAY|ALL)
- layman -f [-o URL]
- layman (-l|-L|-S)"""
+ overlord (-a|-d|-s|-i) (OVERLAY|ALL)
+ overlord -f [-o URL]
+ overlord (-l|-L|-S)"""
class BareConfig(object):
'''Handles the configuration only.'''
@@ -60,7 +60,7 @@ class BareConfig(object):
'nocheck', 'overlays', 'proxy', 'quietness', 'rsync_command', 'storage',
'svn_command', 'tar_command', 'umask', 'width']
'''
- self._defaults = {'config' : '/etc/layman/layman.cfg',
+ self._defaults = {'config' : '/etc/overlord/overlord.cfg',
'storage' : '/var/lib/layman',
'cache' : '%(storage)s/cache',
'local_list': '%(storage)s/overlays.xml',
@@ -146,7 +146,7 @@ class ArgsParser(object):
>>> import os.path
>>> here = os.path.dirname(os.path.realpath(__file__))
>>> sys.argv.append('--config')
- >>> sys.argv.append(here + '/../etc/layman.cfg')
+ >>> sys.argv.append(here + '/../etc/overlord.cfg')
>>> a = ArgsParser()
>>> a['overlays']
'\\nhttp://www.gentoo.org/proj/en/overlays/repositories.xml'
@@ -277,8 +277,8 @@ class ArgsParser(object):
'--quiet',
action = 'store_true',
help = 'Yield no output. Please be careful with this op'
- 'tion: If the processes spawned by layman when adding o'
- 'r synchronizing overlays require any input layman will'
+ 'tion: If the processes spawned by overlord when adding o'
+ 'r synchronizing overlays require any input overlord will'
' hang without telling you why. This might happen for e'
'xample if your overlay resides in subversion and the S'
'SL certificate of the server needs acceptance.')
@@ -286,7 +286,7 @@ class ArgsParser(object):
group.add_option('-N',
'--nocolor',
action = 'store_true',
- help = 'Remove color codes from the layman output.')
+ help = 'Remove color codes from the overlord output.')
group.add_option('-Q',
'--quietness',
@@ -303,7 +303,7 @@ class ArgsParser(object):
type = 'int',
default = '0',
help = 'Sets the screen width. This setting is usually '
- 'not required as layman is capable of detecting the '
+ 'not required as overlord is capable of detecting the '
'available number of columns automatically.')
group.add_option('-k',
@@ -327,7 +327,7 @@ class ArgsParser(object):
sys.exit(0)
(self.options, remain_args) = self.parser.parse_args(args)
# remain_args starts with something like "bin/layman" ...
if len(remain_args) > 1:
self.parser.error("Unhandled parameters: %s"
% ', '.join(('"%s"' % e) for e in remain_args[1:]))
@@ -1,11 +1,11 @@
# File: config.py
#
-# Handles layman configuration
+# Handles overlord configuration
#
# Copyright:
@@ -327,7 +327,7 @@ class ArgsParser(object):
sys.exit(0)
(self.options, remain_args) = self.parser.parse_args(args)
- # remain_args starts with something like "bin/layman" ...
+ # remain_args starts with something like "bin/overlord" ...
if len(remain_args) > 1:
self.parser.error("Unhandled parameters: %s"
diff --git a/layman/constants.py b/overlord/constants.py
index 7fc72ea..f89f286 100644
--- a/layman/constants.py
+++ b/overlord/constants.py
@@ -1,11 +1,11 @@
#!/usr/bin/python
# -*- coding: utf-8 -*-
#################################################################################
-# LAYMAN CONSTANTS
+# overlord CONSTANTS
#################################################################################
# File: constants.py
#
# Handles layman actions via the command line interface.
#
# Copyright:
# (c) 2010 - 2011
@@ -17,7 +17,7 @@
# Gunnar Wrobel <wrobel@gentoo.org>
# Brian Dolbec <brian.dolbec@gmail.com
#
-''' Provides the command line actions that can be performed by layman.'''
+''' Provides the command line actions that can be performed by overlord.'''
__version__ = "$Id: constants.py 2011-01-16 23:52 PST Brian Dolbec$"
@@ -1,11 +1,11 @@
# File: constants.py
#
-# Handles layman actions via the command line interface.
+# Handles overlord actions via the command line interface.
#
# Copyright:
diff --git a/layman/db.py b/overlord/db.py
index 01dc454..d54efa5 100644
--- a/layman/db.py
+++ b/overlord/db.py
@@ -1,7 +1,7 @@
#!/usr/bin/python
# -*- coding: utf-8 -*-
#################################################################################
# LAYMAN OVERLAY DB
#################################################################################
# File: db.py
#
@@ -26,11 +26,11 @@ __version__ = "$Id: db.py 309 2007-04-09 16:23:38Z wrobel $"
import os, os.path, urllib2, hashlib
-from layman.utils import path, delete_empty_directory
-from layman.dbbase import DbBase
-from layman.makeconf import MakeConf
+from overlord.utils import path, delete_empty_directory
+from overlord.dbbase import DbBase
+from overlord.makeconf import MakeConf
-#from layman.debug import OUT
+#from overlord.debug import OUT
#===============================================================================
#
@@ -247,7 +247,7 @@ class RemoteDB(DbBase):
# overrider
def _broken_catalog_hint(self):
- return 'Try running "sudo layman -f" to re-fetch that file'
+ return 'Try running "sudo overlord -f" to re-fetch that file'
def cache(self):
'''
@@ -295,7 +295,7 @@ class RemoteDB(DbBase):
try:
os.makedirs(os.path.dirname(mpath))
except OSError, error:
- raise OSError('Failed to create layman storage direct'
+ raise OSError('Failed to create overlord storage direct'
+ 'ory ' + os.path.dirname(mpath) + '\n'
+ 'Error was:' + str(error))
@@ -1,7 +1,7 @@
# -*- coding: utf-8 -*-
#################################################################################
-# LAYMAN OVERLAY DB
+# overlord OVERLAY DB
#################################################################################
# File: db.py
diff --git a/layman/dbbase.py b/overlord/dbbase.py
index 67c4962..7821aea 100644
--- a/layman/dbbase.py
+++ b/overlord/dbbase.py
@@ -1,7 +1,7 @@
#!/usr/bin/python
# -*- coding: utf-8 -*-
#################################################################################
# LAYMAN OVERLAY HANDLER
#################################################################################
# File: overlay.py
#
@@ -32,9 +32,9 @@ import sys, os, os.path
import xml
import xml.etree.ElementTree as ET # Python 2.5
-#from layman.debug import OUT
-from layman.utils import indent
-from layman.overlays.overlay import Overlay
+#from overlord.debug import OUT
+from overlord.utils import indent
+from overlord.overlays.overlay import Overlay
#===============================================================================
#
@@ -1,7 +1,7 @@
# -*- coding: utf-8 -*-
#################################################################################
-# LAYMAN OVERLAY HANDLER
+# overlord OVERLAY HANDLER
#################################################################################
# File: overlay.py
diff --git a/layman/debug.py b/overlord/debug.py
index 7c42974..eca6266 100644
--- a/layman/debug.py
+++ b/overlord/debug.py
@@ -1,6 +1,6 @@
# -*- coding: utf-8 -*-
#################################################################################
# LAYMAN - DEBUGGING FUNCTIONS
#################################################################################
# debug.py -- Utility function for debugging
# Copyright 2005 - 2008 Gunnar Wrobel
@@ -18,7 +18,7 @@ import sys, inspect, types
from optparse import OptionGroup
-from layman.constants import codes
+from overlord.constants import codes
#################################################################################
@@ -357,7 +357,7 @@ class Message:
for i in error.split('\n'):
# NOTE: Forced flushing ensures that stdout and stderr
# stay in nice order. This is a workaround for calls like
- # "layman -L |& less".
+ # "overlord -L |& less".
sys.stdout.flush()
print >> self.error_out, self.maybe_color('red', '* ') + i
self.error_out.flush()
@@ -512,4 +512,4 @@ class Message:
'////////////////////////////////'
## gloabal message handler
-OUT = Message('layman')
+OUT = Message('overlord')
@@ -1,6 +1,6 @@
# -*- coding: utf-8 -*-
#################################################################################
-# LAYMAN - DEBUGGING FUNCTIONS
+# overlord - DEBUGGING FUNCTIONS
#################################################################################
# debug.py -- Utility function for debugging
diff --git a/layman/overlays/bzr.py b/overlord/overlays/bzr.py
index e73c2f4..0b06f94 100644
--- a/layman/overlays/bzr.py
+++ b/overlord/overlays/bzr.py
@@ -1,7 +1,7 @@
#!/usr/bin/python
# -*- coding: utf-8 -*-
#################################################################################
# LAYMAN BZR OVERLAY HANDLER
#################################################################################
# File: bzr.py
#
@@ -26,8 +26,8 @@ __version__ = "$Id: bzr.py 236 2006-09-05 20:39:37Z wrobel $"
#
#-------------------------------------------------------------------------------
-from layman.utils import path
-from layman.overlays.source import OverlaySource, require_supported
+from overlord.utils import path
+from overlord.overlays.source import OverlaySource, require_supported
#===============================================================================
#
@@ -1,7 +1,7 @@
# -*- coding: utf-8 -*-
#################################################################################
-# LAYMAN BZR OVERLAY HANDLER
+# overlord BZR OVERLAY HANDLER
#################################################################################
# File: bzr.py
diff --git a/layman/overlays/cvs.py b/overlord/overlays/cvs.py
index f8fc277..d40d38e 100644
--- a/layman/overlays/cvs.py
+++ b/overlord/overlays/cvs.py
@@ -1,7 +1,7 @@
#!/usr/bin/python
# -*- coding: utf-8 -*-
#################################################################################
# LAYMAN CVS OVERLAY HANDLER
#################################################################################
# File: cvs.py
#
@@ -26,8 +26,8 @@ __version__ = "$Id$"
import xml.etree.ElementTree as ET # Python 2.5
-from layman.utils import path, ensure_unicode
-from layman.overlays.source import OverlaySource, require_supported
+from overlord.utils import path, ensure_unicode
+from overlord.overlays.source import OverlaySource, require_supported
#===============================================================================
#
@@ -1,7 +1,7 @@
# -*- coding: utf-8 -*-
#################################################################################
-# LAYMAN CVS OVERLAY HANDLER
+# overlord CVS OVERLAY HANDLER
#################################################################################
# File: cvs.py
diff --git a/layman/overlays/darcs.py b/overlord/overlays/darcs.py
index 7d89477..e253861 100644
--- a/layman/overlays/darcs.py
+++ b/overlord/overlays/darcs.py
@@ -1,7 +1,7 @@
#!/usr/bin/python
# -*- coding: utf-8 -*-
#################################################################################
# LAYMAN DARCS OVERLAY HANDLER
#################################################################################
# File: darcs.py
#
@@ -25,8 +25,8 @@ __version__ = "$Id: darcs.py 236 2006-09-05 20:39:37Z wrobel $"
#
#-------------------------------------------------------------------------------
-from layman.utils import path
-from layman.overlays.source import OverlaySource, require_supported
+from overlord.utils import path
+from overlord.overlays.source import OverlaySource, require_supported
#===============================================================================
#
@@ -1,7 +1,7 @@
# -*- coding: utf-8 -*-
#################################################################################
-# LAYMAN DARCS OVERLAY HANDLER
+# overlord DARCS OVERLAY HANDLER
#################################################################################
# File: darcs.py
diff --git a/layman/overlays/g_common.py b/overlord/overlays/g_common.py
index 80d0742..20f2eae 100644
--- a/layman/overlays/g_common.py
+++ b/overlord/overlays/g_common.py
@@ -1,7 +1,7 @@
#!/usr/bin/python
# -*- coding: utf-8 -*-
#################################################################################
# LAYMAN G-COMMON OVERLAY HANDLER
#################################################################################
# File: g_common.py
#
@@ -23,8 +23,8 @@
#-------------------------------------------------------------------------------
import os
-from layman.utils import path
-from layman.overlays.source import OverlaySource, require_supported
+from overlord.utils import path
+from overlord.overlays.source import OverlaySource, require_supported
#===============================================================================
#
@@ -40,7 +40,7 @@ class GCommonOverlay(OverlaySource):
def __init__(self, parent, xml, config, _location, ignore = 0, quiet = False):
super(GCommonOverlay, self).__init__(parent, xml, config, _location, ignore, quiet)
- #split source into driver and remote uri.
+ #split source into driver and remote uri.
self.driver=self.src[:self.src.find(' ')]
self.remote_uri=self.src[self.src.find(' ')+1:]
@@ -1,7 +1,7 @@
# -*- coding: utf-8 -*-
#################################################################################
-# LAYMAN G-COMMON OVERLAY HANDLER
+# overlord G-COMMON OVERLAY HANDLER
#################################################################################
# File: g_common.py
diff --git a/layman/overlays/git.py b/overlord/overlays/git.py
index caa73f4..6aef61b 100644
--- a/layman/overlays/git.py
+++ b/overlord/overlays/git.py
@@ -1,7 +1,7 @@
#!/usr/bin/python
# -*- coding: utf-8 -*-
#################################################################################
# LAYMAN GIT OVERLAY HANDLER
#################################################################################
# File: git.py
#
@@ -24,8 +24,8 @@ __version__ = "$Id: git.py 146 2006-05-27 09:52:36Z wrobel $"
#
#-------------------------------------------------------------------------------
-from layman.utils import path
-from layman.overlays.source import OverlaySource, require_supported
+from overlord.utils import path
+from overlord.overlays.source import OverlaySource, require_supported
#===============================================================================
#
@@ -1,7 +1,7 @@
# -*- coding: utf-8 -*-
#################################################################################
-# LAYMAN GIT OVERLAY HANDLER
+# overlord GIT OVERLAY HANDLER
#################################################################################
# File: git.py
diff --git a/layman/overlays/mercurial.py b/overlord/overlays/mercurial.py
index 06cf59d..f4a7c2c 100644
--- a/layman/overlays/mercurial.py
+++ b/overlord/overlays/mercurial.py
@@ -1,7 +1,7 @@
#!/usr/bin/python
# -*- coding: utf-8 -*-
#################################################################################
# LAYMAN MERCURIAL OVERLAY HANDLER
#################################################################################
# File: darcs.py
#
@@ -25,8 +25,8 @@ __version__ = "$Id: mercurial.py 236 2006-09-05 20:39:37Z wrobel $"
#
#-------------------------------------------------------------------------------
-from layman.utils import path
-from layman.overlays.source import OverlaySource, require_supported
+from overlord.utils import path
+from overlord.overlays.source import OverlaySource, require_supported
#===============================================================================
#
@@ -1,7 +1,7 @@
# -*- coding: utf-8 -*-
#################################################################################
-# LAYMAN MERCURIAL OVERLAY HANDLER
+# overlord MERCURIAL OVERLAY HANDLER
#################################################################################
# File: darcs.py
diff --git a/layman/overlays/overlay.py b/overlord/overlays/overlay.py
index c7c9cce..4a3cae7 100644
--- a/layman/overlays/overlay.py
+++ b/overlord/overlays/overlay.py
@@ -1,7 +1,7 @@
#!/usr/bin/python
# -*- coding: utf-8 -*-
#################################################################################
# LAYMAN OVERLAY BASE CLASS
#################################################################################
# File: overlay.py
#
@@ -33,19 +33,19 @@ import codecs
import locale
import xml.etree.ElementTree as ET # Python 2.5
-from layman.utils import (pad, terminal_width, get_encoding, encoder,
+from overlord.utils import (pad, terminal_width, get_encoding, encoder,
ensure_unicode)
-#from layman.debug import OUT
-
-from layman.overlays.bzr import BzrOverlay
-from layman.overlays.darcs import DarcsOverlay
-from layman.overlays.git import GitOverlay
-from layman.overlays.g_common import GCommonOverlay
-from layman.overlays.mercurial import MercurialOverlay
-from layman.overlays.cvs import CvsOverlay
-from layman.overlays.svn import SvnOverlay
-from layman.overlays.rsync import RsyncOverlay
-from layman.overlays.tar import TarOverlay
+#from overlord.debug import OUT
+
+from overlord.overlays.bzr import BzrOverlay
+from overlord.overlays.darcs import DarcsOverlay
+from overlord.overlays.git import GitOverlay
+from overlord.overlays.g_common import GCommonOverlay
+from overlord.overlays.mercurial import MercurialOverlay
+from overlord.overlays.cvs import CvsOverlay
+from overlord.overlays.svn import SvnOverlay
+from overlord.overlays.rsync import RsyncOverlay
+from overlord.overlays.tar import TarOverlay
#===============================================================================
#
@@ -1,7 +1,7 @@
# -*- coding: utf-8 -*-
#################################################################################
-# LAYMAN OVERLAY BASE CLASS
+# overlord OVERLAY BASE CLASS
#################################################################################
# File: overlay.py
diff --git a/layman/overlays/rsync.py b/overlord/overlays/rsync.py
index 3a5a342..d5dbd48 100644
--- a/layman/overlays/rsync.py
+++ b/overlord/overlays/rsync.py
@@ -1,7 +1,7 @@
#!/usr/bin/python
# -*- coding: utf-8 -*-
#################################################################################
# LAYMAN RSYNC OVERLAY HANDLER
#################################################################################
# File: rsync.py
#
@@ -24,8 +24,8 @@ __version__ = "$Id: rsync.py 236 2006-09-05 20:39:37Z wrobel $"
#
#-------------------------------------------------------------------------------
-from layman.utils import path
-from layman.overlays.source import OverlaySource, require_supported
+from overlord.utils import path
+from overlord.overlays.source import OverlaySource, require_supported
#===============================================================================
#
@@ -1,7 +1,7 @@
# -*- coding: utf-8 -*-
#################################################################################
-# LAYMAN RSYNC OVERLAY HANDLER
+# overlord RSYNC OVERLAY HANDLER
#################################################################################
# File: rsync.py
diff --git a/layman/overlays/source.py b/overlord/overlays/source.py
index a9b5ecf..c645fa8 100644
--- a/layman/overlays/source.py
+++ b/overlord/overlays/source.py
@@ -1,6 +1,6 @@
# -*- coding: utf-8 -*-
#################################################################################
# LAYMAN OVERLAY SOURCE BASE CLASS
#################################################################################
# File: source.py
#
@@ -18,8 +18,8 @@ import copy
import sys
import shutil
import subprocess
-#from layman.debug import OUT
-from layman.utils import path
+#from overlord.debug import OUT
+from overlord.utils import path
def _resolve_command(command):
@@ -1,6 +1,6 @@
# -*- coding: utf-8 -*-
#################################################################################
-# LAYMAN OVERLAY SOURCE BASE CLASS
+# overlord OVERLAY SOURCE BASE CLASS
#################################################################################
# File: source.py
diff --git a/layman/overlays/svn.py b/overlord/overlays/svn.py
index 2a30198..1570450 100644
--- a/layman/overlays/svn.py
+++ b/overlord/overlays/svn.py
@@ -1,7 +1,7 @@
#!/usr/bin/python
# -*- coding: utf-8 -*-
#################################################################################
# LAYMAN SVN OVERLAY HANDLER
#################################################################################
# File: svn.py
#
@@ -24,8 +24,8 @@ __version__ = "$Id: svn.py 236 2006-09-05 20:39:37Z wrobel $"
#
#-------------------------------------------------------------------------------
-from layman.utils import path
-from layman.overlays.source import OverlaySource, require_supported
+from overlord.utils import path
+from overlord.overlays.source import OverlaySource, require_supported
#===============================================================================
#
@@ -1,7 +1,7 @@
# -*- coding: utf-8 -*-
#################################################################################
-# LAYMAN SVN OVERLAY HANDLER
+# overlord SVN OVERLAY HANDLER
#################################################################################
# File: svn.py
diff --git a/layman/overlays/tar.py b/overlord/overlays/tar.py
index 4916b77..425fe26 100644
--- a/layman/overlays/tar.py
+++ b/overlord/overlays/tar.py
@@ -1,7 +1,7 @@
#!/usr/bin/python
# -*- coding: utf-8 -*-
#################################################################################
# LAYMAN TAR OVERLAY HANDLER
#################################################################################
# File: tar.py
#
@@ -27,9 +27,9 @@ __version__ = "$Id: tar.py 310 2007-04-09 16:30:40Z wrobel $"
import os, os.path, sys, urllib2, shutil, tempfile
import xml.etree.ElementTree as ET # Python 2.5
-from layman.utils import path, ensure_unicode
-#from layman.debug import OUT
-from layman.overlays.source import OverlaySource, require_supported
+from overlord.utils import path, ensure_unicode
+#from overlord.debug import OUT
+from overlord.overlays.source import OverlaySource, require_supported
#===============================================================================
#
@@ -40,7 +40,7 @@ from layman.overlays.source import OverlaySource, require_supported
class TarOverlay(OverlaySource):
''' Handles tar overlays.
- >>> from layman.debug import OUT
+ >>> from overlord.debug import OUT
>>> import xml.etree.ElementTree as ET # Python 2.5
>>> repo = ET.Element('repo')
>>> repo_name = ET.Element('name')
@@ -53,14 +53,14 @@ class TarOverlay(OverlaySource):
>>> owner[:] = [owner_email]
>>> source = ET.Element('source', type='tar')
>>> here = os.path.dirname(os.path.realpath(__file__))
- >>> source.text = 'file://' + here + '/../tests/testfiles/layman-test.tar.bz2'
+ >>> source.text = 'file://' + here + '/../tests/testfiles/overlord-test.tar.bz2'
>>> subpath = ET.Element('subpath')
- >>> subpath.text = 'layman-test'
+ >>> subpath.text = 'overlord-test'
>>> repo[:] = [repo_name, desc, owner, source, subpath]
>>> config = {'tar_command':'/bin/tar'}
>>> testdir = os.tmpnam()
>>> os.mkdir(testdir)
- >>> from layman.overlays.overlay import Overlay
+ >>> from overlord.overlays.overlay import Overlay
>>> a = Overlay(repo, config, quiet=False)
>>> OUT.color_off()
>>> a.add(testdir) #doctest: +ELLIPSIS
@@ -1,7 +1,7 @@
# -*- coding: utf-8 -*-
#################################################################################
-# LAYMAN TAR OVERLAY HANDLER
+# overlord TAR OVERLAY HANDLER
#################################################################################
# File: tar.py
diff --git a/layman/tests/dtest.py b/overlord/tests/dtest.py
index 5edd6ce..d380b7f 100644
--- a/layman/tests/dtest.py
+++ b/overlord/tests/dtest.py
@@ -1,7 +1,7 @@
#!/usr/bin/python
# -*- coding: utf-8 -*-
#################################################################################
# LAYMAN DOCTEST AGGREGATOR
#################################################################################
# File: dtest.py
#
@@ -49,13 +49,13 @@ import unittest, doctest
# clean but no testing : CN
# unclean but no testing: UN
-import layman.action #CT
-import layman.config #CT
-import layman.db #CT
-import layman.dbbase #CT
-import layman.utils #CT
-import layman.overlays.overlay #CT
-import layman.overlays.tar #CT
+import overlord.action #CT
+import overlord.config #CT
+import overlord.db #CT
+import overlord.dbbase #CT
+import overlord.utils #CT
+import overlord.overlays.overlay #CT
+import overlord.overlays.tar #CT
#===============================================================================
#
@@ -65,13 +65,13 @@ import layman.overlays.tar #CT
def test_suite():
return unittest.TestSuite((
- doctest.DocTestSuite(layman.action),
- doctest.DocTestSuite(layman.config),
- doctest.DocTestSuite(layman.db),
- doctest.DocTestSuite(layman.dbbase),
- doctest.DocTestSuite(layman.utils),
- doctest.DocTestSuite(layman.overlays.overlay),
- doctest.DocTestSuite(layman.overlays.tar),
+ doctest.DocTestSuite(overlord.action),
+ doctest.DocTestSuite(overlord.config),
+ doctest.DocTestSuite(overlord.db),
+ doctest.DocTestSuite(overlord.dbbase),
+ doctest.DocTestSuite(overlord.utils),
+ doctest.DocTestSuite(overlord.overlays.overlay),
+ doctest.DocTestSuite(overlord.overlays.tar),
))
#===============================================================================
@@ -1,7 +1,7 @@
# -*- coding: utf-8 -*-
#################################################################################
-# LAYMAN DOCTEST AGGREGATOR
+# overlord DOCTEST AGGREGATOR
#################################################################################
# File: dtest.py
diff --git a/layman/tests/external.py b/overlord/tests/external.py
index 3c23373..aa43a3f 100644
--- a/layman/tests/external.py
+++ b/overlord/tests/external.py
@@ -1,6 +1,6 @@
# -*- coding: utf-8 -*-
#################################################################################
# EXTENRAL LAYMAN TESTS
#################################################################################
# File: external.py
#
@@ -20,7 +20,7 @@ import os
import tempfile
import shutil
import urllib
-from layman.dbbase import DbBase
+from overlord.dbbase import DbBase
from warnings import filterwarnings, resetwarnings
HERE = os.path.dirname(os.path.realpath(__file__))
@@ -64,7 +64,7 @@ class FormatSubpathCategory(unittest.TestCase):
os1 = self._run(1)
os2 = self._run(2)
# Same content from old/layman-global.txt
# and new/repositories.xml format?
self.assertTrue(os1 == os2)
@@ -73,7 +73,7 @@ class FormatSubpathCategory(unittest.TestCase):
class TarAddRemoveSync(unittest.TestCase):
def test(self):
repo_name = 'tar-test-overlay'
- tar_source_path = os.path.join(HERE, 'testfiles', 'layman-test.tar.bz2')
+ tar_source_path = os.path.join(HERE, 'testfiles', 'overlord-test.tar.bz2')
# Duplicate test tarball (so we have it deletable for later)
(_, temp_tarball_path) = tempfile.mkstemp()
@@ -1,6 +1,6 @@
# -*- coding: utf-8 -*-
#################################################################################
-# EXTENRAL LAYMAN TESTS
+# EXTENRAL overlord TESTS
#################################################################################
# File: external.py
@@ -64,7 +64,7 @@ class FormatSubpathCategory(unittest.TestCase):
os1 = self._run(1)
os2 = self._run(2)
- # Same content from old/layman-global.txt
+ # Same content from old/overlord-global.txt
# and new/repositories.xml format?
self.assertTrue(os1 == os2)